############################
Getting help using *groupyr*
############################

If you run into any bugs or issues using *groupyr*, please let us know by
`posting an issue <https://github.com/richford/groupyr/issues/new/choose>`_.
on our GitHub repository. You can browse existing issues `here
<https://github.com/richford/groupyr/issues>`_. Please provide all pertinent
information about the issue you are facing: we often need to know what
version of the software you are running and how you installed it, as well as
the operating system that you are using. If you run into issues with your
data, we might ask you to share a small sample of your data with us, so that
we can examine it. Please make sure that your study ethics procedure allows
you to share this data before sending it on to us.
